@@ -83,7 +83,7 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
     def poke(self, context: dict) -> bool:
         self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
         hook = GCSHook(
-            google_cloud_storage_conn_id=self.google_cloud_conn_id,
+            gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
@@ -160,7 +160,7 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
     def poke(self, context: dict) -> bool:
         self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
         hook = GCSHook(
-            google_cloud_storage_conn_id=self.google_cloud_conn_id,
+            gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
@@ -226,7 +226,7 @@ class GCSObjectsWtihPrefixExistenceSensor(BaseSensorOperator):
     def poke(self, context: dict) -> bool:
         self.log.info('Sensor checks existence of objects: %s, %s', self.bucket, self.prefix)
         hook = GCSHook(
-            google_cloud_storage_conn_id=self.google_cloud_conn_id,
+            gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
